# WARNING - Generated by {fusen} from /dev/flat_full.Rmd: do not edit by hand



# Test cases for getLabelExpected function
test_that("getLabelExpected assigns labels correctly", {
  

    # Sample comparison data frame
  comparison_data <- data.frame(
      geneID = c("gene1", "gene2", "gene3"),
      actual = c(0.5, -0.3, 0.8)
  )
  
  # Test case 1: Alt hypothesis = "greater"
  labeled_data_greater <- getLabelExpected(comparison_data, coeff_threshold = 0.2, alt_hypothesis = "greater")
  expect_identical(labeled_data_greater$isDE, c(TRUE, FALSE, TRUE))
  
  # Test case 2: Alt hypothesis = "less"
  labeled_data_less <- getLabelExpected(comparison_data, coeff_threshold = -0.2, alt_hypothesis = "less")
  expect_identical(labeled_data_less$isDE, c(FALSE, TRUE, FALSE))
  
  # Test case 3: Alt hypothesis = "greaterAbs"
  labeled_data_greaterAbs <- getLabelExpected(comparison_data, coeff_threshold = 0.6, alt_hypothesis = "greaterAbs")
  expect_identical(labeled_data_greaterAbs$isDE, c(FALSE, FALSE, TRUE))
  
})





test_that("compute_roc_curve computes ROC curve from data frame", {
  # Test data
  dt <- data.frame(
    isDE = c(1, 0, 1, 0, 1),
    p.adj = c(0.8, 0.6, 0.7, 0.4, 0.9)
  )

  # Test
  result <- compute_roc_curve(dt)
  expect_equal(names(result), c("False positive rate", "True positive rate"))
})

test_that("compute_roc_auc computes AUC from data frame", {
  # Test data
  dt <- data.frame(
    isDE = c(0, 1, 1, 0, 0, 0, 1),
    p.adj = c(1, 0.75, 0.75, 0.5, 0.25, 0, 0.1)
  )
  
  roc_curve_obj <- compute_roc_curve(dt)
  # Test
  result <- compute_roc_auc(roc_curve_obj)
  
   # Expected output
  expected_result <- 0.42
  expect_equal(round(result,2 ), expected_result)
})

test_that("get_roc_object returns ROC curves and AUCs", {
  # Test data
  set.seed(101)
  evaldata_params <- data.frame(
    from = rep(c("HTRfit", "DESeq2"), each = 5),
    description = rep(c("param1", "param2"), each = 5),
    isDE = sample(0:1, 10, replace = TRUE),
    p.adj = runif(10),
    effect = rep("fixed", 10)
  )

  # Test
  result <- get_roc_object(evaldata_params)
  expect_equal(names(result), c("byparams", "aggregate"))
  expect_equal(names(result$byparams), c("roc_curve", "roc_auc"))
  expect_equal(names(result$aggregate), c("roc_curve", "roc_auc"))
  
  ## -- not only fixed effect 
  set.seed(101)
  evaldata_params <- data.frame(
    from = rep(c("HTRfit", "DESeq2"), each = 5),
    description = rep(c("param1", "param2"), each = 5),
    isDE = sample(0:1, 10, replace = TRUE),
    p.adj = runif(10),
    effect = c(rep("fixed", 8), 'ran_pars', 'ran_pars')
  )
    
  result <- get_roc_object(evaldata_params)
  expect_equal(names(result), c("byparams", "aggregate"))
  expect_equal(names(result$byparams), c("roc_curve", "roc_auc"))
  expect_equal(names(result$aggregate), c("roc_curve", "roc_auc"))
  

    
})

test_that("build_gg_roc_curve builds ggplot ROC curve", {
  # Test data
  data_curve <- data.frame(
    .threshold = c(-Inf, 0.9, 0.8, 0.7, 0.6, 0.4, Inf),
    specificity = c(0, 1, 0.75, 0.5, 0.25, 0, 1),
    sensitivity = c(1, 0.75, 0.75, 0.5, 0.25, 0, 0),
    from = rep("HTRfit", 7)
  )
  data_auc <- data.frame(from = "HTRfit", AUC = 0.6875)

  # Test
  result <- build_gg_roc_curve(data_curve, data_auc)
  # Ensure that the ggplot object is created without errors
  expect_true("gg" %in% class(result))
})

test_that("get_label_y_position computes y-axis positions for labels", {
  # Test data
  data_auc <- data.frame(from = rep(c("HTRfit", "DESeq2"), each = 2), AUC = c(1, 0.90))

  # Expected output
  expected_result <- data.frame(from = rep(c("HTRfit", "DESeq2"), each = 2), AUC = c(1, 0.90), pos_y = c(0.05, 0.05, 0.15, 0.15))

  # Test
  result <- get_label_y_position(data_auc)
  expect_equal(result, expected_result)
})



